============
 Modern base
============
------------------------------
 An installable theme for Plone 5
------------------------------

`Latest version on PyPI <https://pypi.python.org/pypi/plonetheme.modernbase>`_

Documentation
=============
- Based on the Plone 5 theme `Clean Blog <https://pypi.python.org/pypi/plonetheme.clean-blog>`_

Installation
============================
Install plonetheme.modernbase by adding it to your buildout::

    [buildout]

    ...

    eggs =
        plonetheme.modernbase

and then running ``bin/buildout``

Source Code and Contribution
============================

Source-Code
    at the `Plone code repository hosted at Github <https://github.com/intk/plonetheme.modernbase>`_.

Issues
    Please use the `Issue-Tracker <https://github.com/intk/plonetheme.modernbase/issues>`_

